==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/sms/translations/sms_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Přezdívka SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Použít vestavěný program na SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Vlastní program na SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Použít vlastní řetězec SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Vlastní řetězec SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Server SMS</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Server T-Mobile.pl SMS</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponzorovaný</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Uživatelovo ID (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange Multibox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Sende SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Příjemce</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Vybrat automaticky</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Poskytovatel GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Uložit SMS v historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Poslat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Program pro SMS nebyl určen. Navštivte oddíl s nastavením</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Nepodařilo se dát vzniknout procesu potamka. Ověřte, že je program funkční</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces skončil neobvykle. SMS nebyla poslána</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Přečtěte text z obrázku a napište jej zde:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Unable to fetch required token</source>
        <translation>Nepodařilo se natáhnout požadovaný symbol</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Podpis nemůže být prázdný</translation>
    </message>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatický výběr serveru není dostupný. Vyberte, prosím, server SMS ručně.</translation>
    </message>
</context>
<context>
    <name>SmsProgressWindow</name>
    <message>
        <source>Sending SMS in progress.</source>
        <translation>Posílání SMS na postupu.</translation>
    </message>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Napište text z obrázku</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>SMS sent successfully</source>
        <translation>SMS úspěšně poslána</translation>
    </message>
</context>
</TS>

==> kadu-0.12.1.tar.bz2: kadu-0.12.1/plugins/sms/translations/sms_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Přezdívka SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Použít vestavěný program na SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Vlastní program na SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Použít vlastní řetězec SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Vlastní řetězec SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Server SMS</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Server T-Mobile.pl SMS</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponzorovaný</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Uživatelovo ID (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Sende SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Příjemce</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Vybrat automaticky</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Poskytovatel GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Uložit SMS v historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Poslat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Program pro SMS nebyl určen. Navštivte oddíl s nastavením</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Nepodařilo se dát vzniknout procesu potamka. Ověřte, že je program funkční</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces skončil neobvykle. SMS nebyla poslána</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatický výběr serveru není dostupný. Vyberte, prosím, server SMS ručně.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
